==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/plugins/Visual/projectm/translations/projectm_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>&amp;Help</source>
        <translation>Aj&amp;uda</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>&amp;Show Song Title</source>
        <translation>Mo&amp;strar título da faixa</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>&amp;Show Preset Name</source>
        <translation>M&amp;ostrar nome do pré-ajuste</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>&amp;Show Menu</source>
        <translation>&amp;Mostrar menu</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>&amp;Next Preset</source>
        <translation>Pré-ajuste segui&amp;nte</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Pré-ajuste anterior</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>&amp;Random Preset</source>
        <translation>P&amp;ré-ajuste aleatório</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>&amp;Lock Preset</source>
        <translation>B&amp;loquear pré-ajuste</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Ecrã completo</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Sobre o suplemento ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Seuplemento Qmmp ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Este suplemento disponibiliza as visualizações ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on libprojectM-qt library</source>
        <translation>Baseado na biblioteca libprojectM-qt</translation>
    </message>
</context>
</TS>

==> qmmp-0.8.5.tar.bz2: qmmp-0.8.5/src/plugins/Visual/projectm/translations/projectm_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>&amp;Help</source>
        <translation>Aj&amp;uda</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>&amp;Show Song Title</source>
        <translation>Mo&amp;strar título da faixa</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>&amp;Show Preset Name</source>
        <translation>M&amp;ostrar nome do pré-ajuste</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>&amp;Show Menu</source>
        <translation>&amp;Mostrar menu</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>&amp;Next Preset</source>
        <translation>Pré-ajuste segui&amp;nte</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Pré-ajuste anterior</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>&amp;Random Preset</source>
        <translation>P&amp;ré-ajuste aleatório</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>&amp;Lock Preset</source>
        <translation>B&amp;loquear pré-ajuste</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Ecrã completo</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Sobre o suplemento ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Suplemento Qmmp ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Este suplemento disponibiliza as visualizações ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on libprojectM-qt library</source>
        <translation>Baseado na biblioteca libprojectM-qt</translation>
    </message>
</context>
</TS>
